
The plugin provides Oauth authentication on data job startup.

# Usage

To install the plugin, run:

```bash
pip install vdk-oauth-auth
```

## Configuration

The following environment variables can be used to configure this plugin:

| name                 | description                                   |
|----------------------|-----------------------------------------------|
| `TEAM_CLIENT_ID`     | Client id to fetch access token from CSP.     |
| `TEAM_CLIENT_SECRET` | Client secret to fetch access token from CSP. |
